require 'aha/version'
require 'aha/augmented_hash'

# Extends Hash with functionality from Aha::AugmentedHash.
#
# Methods are implemented by delegating to AugmentedHash on an individual method
# basis. Using module methods as opposed to a mixing in a module is preferrable
# as it allows us to include functionality in a piecemeal manner if necessary
# and supports minimal changes to the core Hash class.
#
# For more information see Aha::AugmentedHash.
class Hash
  def vals_at(*keys)
    Aha::AugmentedHash::vals_at(self, *keys)
  end

  def get_in(*keys)
    Aha::AugmentedHash::get_in(self, *keys)
  end

  def put_in!(*args)
    Aha::AugmentedHash::put_in!(self, *args)
  end

  def update_in!(*keys, &block)
    Aha::AugmentedHash::update_in!(self, *keys, &block)
  end

  def delete_in!(*keys)
    Aha::AugmentedHash::delete_in!(self, *keys)
  end

  def exclude!(*keys)
    Aha::AugmentedHash::exclude!(self, *keys)
  end

  def only(*keys)
    Aha::AugmentedHash::only(self, *keys)
  end
end
